==> code_saturne-8.1.1-3-x86_64.pkg.tar.zst: usr/share/doc/code_saturne/doxygen/src/cs__gradient_8h.js <==
var cs__gradient_8h =
[
    [ "cs_gradient_limit_t", "cs__gradient_8h.html#a5a83a1b0d020497f0a3beecc4b234aa6", [
      [ "CS_GRADIENT_LIMIT_NONE", "cs__gradient_8h.html#a5a83a1b0d020497f0a3beecc4b234aa6ac83a003fc6643c8baa8b4137ed0807ff", null ],
      [ "CS_GRADIENT_LIMIT_CELL", "cs__gradient_8h.html#a5a83a1b0d020497f0a3beecc4b234aa6aadf174ef875f9be0cff2ba71a59dd19e", null ],
      [ "CS_GRADIENT_LIMIT_FACE", "cs__gradient_8h.html#a5a83a1b0d020497f0a3beecc4b234aa6afeb798b0430c5984b44f56c78bcfbf50", null ]
    ] ],
    [ "cs_gradient_type_t", "cs__gradient_8h.html#a47b2817b6f73eb8b86f4d3c99fd6ba25", [
      [ "CS_GRADIENT_GREEN_ITER", "cs__gradient_8h.html#a47b2817b6f73eb8b86f4d3c99fd6ba25a9d607f2b84bb8a19967fd5a6b07cc0b1", null ],
      [ "CS_GRADIENT_LSQ", "cs__gradient_8h.html#a47b2817b6f73eb8b86f4d3c99fd6ba25a10e2294f5d60b39e4c5959a397561693", null ],
      [ "CS_GRADIENT_GREEN_LSQ", "cs__gradient_8h.html#a47b2817b6f73eb8b86f4d3c99fd6ba25a7095caba392370f20cff0ed9be423b43", null ],
      [ "CS_GRADIENT_GREEN_VTX", "cs__gradient_8h.html#a47b2817b6f73eb8b86f4d3c99fd6ba25af4203f53e48103cb965ea65e92b3be1d", null ],
      [ "CS_GRADIENT_GREEN_R", "cs__gradient_8h.html#a47b2817b6f73eb8b86f4d3c99fd6ba25a7a3584bc2c2ac09d0ac09f24059c48dc", null ]
    ] ],
    [ "cs_gradient_finalize", "cs__gradient_8h.html#ab10268dcee7f0eb203e488ad40d61e8d", null ],
    [ "cs_gradient_free_quantities", "cs__gradient_8h.html#aedc1dec344dcae199b17dc4ca33303b7", null ],
    [ "cs_gradient_initialize", "cs__gradient_8h.html#ad349221ea4d3b534a8b828aae4d945d7", null ],
    [ "cs_gradient_porosity_balance", "cs__gradient_8h.html#a5fca186eebf89682c70ddcde2bcaf56b", null ],
    [ "cs_gradient_scalar", "cs__gradient_8h.html#afe89bcfca395536160157709576b44a6", null ],
    [ "cs_gradient_scalar_cell", "cs__gradient_8h.html#af7d0a70d1d6a72e994d7b967b5975b58", null ],
    [ "cs_gradient_scalar_synced_input", "cs__gradient_8h.html#a670f1ec5375c48f66ab1d194bba68da5", null ],
    [ "cs_gradient_tensor", "cs__gradient_8h.html#a24a7ff429730f319a11473a7e393b4fe", null ],
    [ "cs_gradient_tensor_cell", "cs__gradient_8h.html#ac3cdff129777f7be7d74ef743eede8a0", null ],
    [ "cs_gradient_tensor_synced_input", "cs__gradient_8h.html#a39fc50ed06440ccf697b4af614d4d94b", null ],
    [ "cs_gradient_type_by_imrgra", "cs__gradient_8h.html#a1a188452a451e66677941e7a0ac2e0ab", null ],
    [ "cs_gradient_vector", "cs__gradient_8h.html#af976bc22b4fe044fb6a5557dd2955eba", null ],
    [ "cs_gradient_vector_cell", "cs__gradient_8h.html#a9b2a199134fc4fde8a627a866313cd6e", null ],
    [ "cs_gradient_vector_synced_input", "cs__gradient_8h.html#a13ee6f65d6bb8bdf3a421a632b4f3d5c", null ],
    [ "cs_gradient_type_name", "cs__gradient_8h.html#a47cf0fc838cdcc56afd6d9b07ed1d730", null ]
];

==> code_saturne-9.1.0-1-x86_64.pkg.tar.zst: usr/share/doc/code_saturne/doxygen/src/cs__gradient_8h.js <==
var cs__gradient_8h =
[
    [ "B_DIRECTION_LSQ", "cs__gradient_8h.html#a8182d055787759b17dbe73e89bf5c5cb", null ],
    [ "CS_IF_LSQ", "cs__gradient_8h.html#a916d33d3684e8c75d1d41051e80f83a1", null ],
    [ "CS_IPRIME_F_LSQ", "cs__gradient_8h.html#ad903a5084182a574a27fc609eb443c81", null ],
    [ "cs_gradient_limit_t", "cs__gradient_8h.html#a5a83a1b0d020497f0a3beecc4b234aa6", [
      [ "CS_GRADIENT_LIMIT_NONE", "cs__gradient_8h.html#a5a83a1b0d020497f0a3beecc4b234aa6ac83a003fc6643c8baa8b4137ed0807ff", null ],
      [ "CS_GRADIENT_LIMIT_CELL", "cs__gradient_8h.html#a5a83a1b0d020497f0a3beecc4b234aa6aadf174ef875f9be0cff2ba71a59dd19e", null ],
      [ "CS_GRADIENT_LIMIT_FACE", "cs__gradient_8h.html#a5a83a1b0d020497f0a3beecc4b234aa6afeb798b0430c5984b44f56c78bcfbf50", null ]
    ] ],
    [ "cs_gradient_type_t", "cs__gradient_8h.html#a47b2817b6f73eb8b86f4d3c99fd6ba25", [
      [ "CS_GRADIENT_GREEN_ITER", "cs__gradient_8h.html#a47b2817b6f73eb8b86f4d3c99fd6ba25a9d607f2b84bb8a19967fd5a6b07cc0b1", null ],
      [ "CS_GRADIENT_LSQ", "cs__gradient_8h.html#a47b2817b6f73eb8b86f4d3c99fd6ba25a10e2294f5d60b39e4c5959a397561693", null ],
      [ "CS_GRADIENT_GREEN_LSQ", "cs__gradient_8h.html#a47b2817b6f73eb8b86f4d3c99fd6ba25a7095caba392370f20cff0ed9be423b43", null ],
      [ "CS_GRADIENT_GREEN_VTX", "cs__gradient_8h.html#a47b2817b6f73eb8b86f4d3c99fd6ba25af4203f53e48103cb965ea65e92b3be1d", null ],
      [ "CS_GRADIENT_GREEN_R", "cs__gradient_8h.html#a47b2817b6f73eb8b86f4d3c99fd6ba25a7a3584bc2c2ac09d0ac09f24059c48dc", null ]
    ] ],
    [ "cs_gradient_finalize", "cs__gradient_8h.html#ab10268dcee7f0eb203e488ad40d61e8d", null ],
    [ "cs_gradient_free_quantities", "cs__gradient_8h.html#aedc1dec344dcae199b17dc4ca33303b7", null ],
    [ "cs_gradient_initialize", "cs__gradient_8h.html#ad349221ea4d3b534a8b828aae4d945d7", null ],
    [ "cs_gradient_porosity_balance", "cs__gradient_8h.html#a5fca186eebf89682c70ddcde2bcaf56b", null ],
    [ "cs_gradient_scalar", "cs__gradient_8h.html#a19d40c44c12dc9c8608f6bab28a9f512", null ],
    [ "cs_gradient_scalar_cell", "cs__gradient_8h.html#a1b653a95f7a6edac6184be5cf4459d93", null ],
    [ "cs_gradient_scalar_synced_input", "cs__gradient_8h.html#a8ce9b26307f069068a33a7b4af21de5d", null ],
    [ "cs_gradient_tensor", "cs__gradient_8h.html#a8ad0f788278678897f08dc68b2be7854", null ],
    [ "cs_gradient_tensor_cell", "cs__gradient_8h.html#a6aa947be1f8490a7c47415978da010fe", null ],
    [ "cs_gradient_tensor_synced_input", "cs__gradient_8h.html#ac103334055860672dcdd4e648e23cb3b", null ],
    [ "cs_gradient_type_by_imrgra", "cs__gradient_8h.html#a1a188452a451e66677941e7a0ac2e0ab", null ],
    [ "cs_gradient_vector", "cs__gradient_8h.html#a203cc9e48e87496e98024d6b080ff32e", null ],
    [ "cs_gradient_vector_cell", "cs__gradient_8h.html#abe10bd2bded9e869c20d8cf49f3550d2", null ],
    [ "cs_gradient_vector_synced_input", "cs__gradient_8h.html#adecb2671e76ae7522aed66ef9aa76027", null ],
    [ "cs_gradient_type_name", "cs__gradient_8h.html#a47cf0fc838cdcc56afd6d9b07ed1d730", null ]
];
